devicemgmtdialogsplugin/inc/fotadevicedialogs.h
changeset 67 fdbfe0a95492
parent 47 d316aecb87fd
--- a/devicemgmtdialogsplugin/inc/fotadevicedialogs.h	Fri Sep 17 19:58:05 2010 +0530
+++ b/devicemgmtdialogsplugin/inc/fotadevicedialogs.h	Fri Oct 15 11:39:02 2010 +0530
@@ -27,39 +27,53 @@
 #include "syncmlnotifierprivate.h"
 #include "devicemanagementnotifierwidget_p.h"
 
+#include <QObject>
 
-class fotadevicedialogs:public HbDialog, public HbDeviceDialogInterface {
-//class fotadevicedialogs:public devicemanagementnotifierwidget {
+
+class fotadevicedialogs:public QObject
+{
+
 
 Q_OBJECT
 
 public:
-/**
-  * Construction and setting of observer happens here
-  *
-  * @since   S60   SF4
-  * @param   aType - tell sthe type of the dialog to be shown
-  * @param   aObserver is the parent class which owns the notifier and information is
-  * passed to the parent class from the device dialog.
-  */
+		/**
+		  * Construction and setting of observer happens here
+		  *
+		  * @since   SF4
+		  * @param   ptr - pointer to the devicemanagementnotifierwidget which sends the data to the calling module.
+		  * passed to the parent class from the device dialog.
+		  */
+		
+		fotadevicedialogs(devicemanagementnotifierwidget* ptr);
+		
+		
+		/**
+		  * Destructor to release the memory
+		  *
+		  * @since   SF4
+		  * @param   None
+		  */
+		  
+		~fotadevicedialogs();
 
-fotadevicedialogs(const QVariantMap &parameters);
-
-private:
-    /**
+		/**
       * Function to call the appropriate device dialog based on the dialog ID.
       *
-      * @since   S60   SF4
+      * @since   SF4
       * @param   aType - tell sthe type of the dialog to be shown
       * @param   parameters - contains the dialogID + information to be shown in the dialogs
       */
 
      void launchFotaDialog(const QVariantMap &parameters);
-     
+
+
+private:
+         
      /**
        * Function to show the informative dialog of FOTA
        *
-       * @since   S60   SF4
+       * @since   SF4
        * @param   aType - tell sthe type of the dialog to be shown
        * @param   parameters - contains the dialogID + information to be shown in the dialogs
        */
@@ -69,7 +83,7 @@
      /**
         * Function to show the error message dialog of FOTA
         *
-        * @since   S60   SF4
+        * @since   SF4
         * @param   aType - tell sthe type of the dialog to be shown
         * @param   parameters - contains the dialogID + information to be shown in the dialogs
         */
@@ -79,7 +93,7 @@
      /**
          * Function to show the confirmative dialog of FOTA
          *
-         * @since   S60   SF4
+         * @since  SF4
          * @param   aType - tell sthe type of the dialog to be shown
          * @param   parameters - contains the dialogID + information to be shown in the dialogs
          */
@@ -87,56 +101,34 @@
 
 public slots:
 
-/**
-  * Construction and setting of observer happens here
-  *
-  * @since   S60   SF4
-  * @param   aObserver is the parent class which owns the notifier and information is
-  * passed to the parent class from the device dialog.
-  */
-
+		/**
+	  * Construction and setting of observer happens here
+	  *
+	  * @since   SF4
+	  * @param   aObserver is the parent class which owns the notifier and information is
+	  * passed to the parent class from the device dialog.
+	  */
     void fotaLSK();
+    
     /**
-      * Construction and setting of observer happens here
-      *
-      * @since   S60   SF4
-      * @param   aObserver is the parent class which owns the notifier and information is
-      * passed to the parent class from the device dialog.
-      */
-
+    * Construction and setting of observer happens here
+    *
+    * @since   SF4
+    * @param   aObserver is the parent class which owns the notifier and information is
+    * passed to the parent class from the device dialog.
+    */
     void fotaRSK();
     
-
-public: //derived from HbDeviceDialogInterface
-    /**
-      * Ccalled when device dialog is closed.
-      *
-      * @since   S60   SF4
-      * @param   byClient - The Name of the client which closed the dialog.
-      */
-
-	void closeDeviceDialog(bool byClient);
+private:
+    
+    // The dialog ID of the current shown dialog.
+    TInt m_DialogId;
     
-    bool setDeviceDialogParameters(const QVariantMap &parameters);
-    int deviceDialogError() const;
-//    void closeDeviceDialog(bool byClient);
-    HbDialog *deviceDialogWidget() const;
-
-signals:
-        void deviceDialogClosed();
-        void deviceDialogData(QVariantMap data);
-
-
-signals:
-/**
-  * servertextmessage
-  *
-  * @since   S60   SF4
-  * @param   aObserver is the parent class which owns the notifier and information is
-  * passed to the parent class from the device dialog.
-  */
-
-    void servertextmessage(const QString &string);
+    // HbDialog instance which actually shows the dialog from the docml.
+    HbDialog* m_dialog;
+    
+    // widget pointer which is used to send the signals to the calling module.
+    devicemanagementnotifierwidget* m_Ptr;
 };
 
 #endif